# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_without repolib

%define repodir %{_javadir}/repository.jboss.com/trove/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define section devel
%define old_name gnu.trove
%define short_name trove

Name:           gnu-%{short_name}
Version:        1.0.2
Release:        7.1.3%{?dist}
Epoch:          0
Summary:        High performance collections for Java
License:        LGPLv2+
URL:            http://trove4j.sourceforge.net/
Group:          Development/Libraries/Java
Source0:        trove-1.0.2.tar.gz
Source1:        trove-build.xml
Source2:        gnu-trove-component-info.xml
#http://repo2.maven.org/maven2/trove/trove/1.0.2/trove-1.0.2.pom
Source3:        gnu-trove-1.0.2.pom
Source4:        gnu-trove-upload.sh
BuildRequires:  jpackage-utils >= 0:1.6
BuildRequires:  ant >= 0:1.6
BuildRequires:  ant-junit >= 0:1.6
BuildRequires:  junit
# To create content for maven2-brew
BuildRequires:  maven-deploy-plugin
Obsoletes:      %{old_name} < %{epoch}:%{version}-%{release}
Provides:       %{old_name} = %{epoch}:%{version}-%{release}
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
The GNU Trove library has two objectives: 

Provide "free" (as in "free speech" and "free beer"), 
fast, lightweight implementations of the java.util 
Collections API. These implementations are designed 
to be pluggable replacements for their JDK equivalents. 

Whenever possible, provide the same collections support 
for primitive types. This gap in the JDK is often 
addressed by using the "wrapper" classes 
(java.lang.Integer, java.lang.Float, etc.) with 
Object-based collections. For most applications, however, 
collections which store primitives directly will require 
less space and yield significant performance gains. 

%if %with repolib
%package repolib
Summary:      Artifacts to be uploaded to a repository library
Group:        Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Obsoletes:      %{old_name}-javadoc < %{epoch}:%{version}-%{release}
Provides:       %{old_name}-javadoc = %{epoch}:%{version}-%{release}

%description javadoc
%{summary}.

%prep
%setup -q -n %{short_name}-%{version}
cp -p %{SOURCE1} build.xml

# remove all binary libs
find . -name "*.jar" -exec rm -f {} \;

%build
export OPT_JAR_LIST="ant/ant-junit junit"
export CLASSPATH=
ant -Dbuild.sysclasspath=only dist

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p target/%{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{short_name}-%{version}.jar
ln -s %{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
ln -s %{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{old_name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr dist/docs/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%if %with repolib
install -d -m 755 $RPM_BUILD_ROOT%{repodir}
install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
install -p -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@VERSION@/%{version}-brew/g" %{buildroot}%{repodir}/component-info.xml
install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
cp -p $RPM_BUILD_ROOT%{_javadir}/trove.jar $RPM_BUILD_ROOT%{repodirlib}/trove.jar
install -p -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{repodirlib}/trove.pom
install -p -m 755 %{SOURCE4} $RPM_BUILD_ROOT%{repodir}/upload.sh
pushd $RPM_BUILD_ROOT%{repodir}
./upload.sh $RPM_BUILD_ROOT/usr/share/java/repository.jboss.com/maven2-brew/
popd
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(0644,root,root,0755)
%doc LICENSE.txt
%{_javadir}*/%{name}-%{version}.jar
%{_javadir}*/%{name}.jar
%{_javadir}*/%{old_name}-%{version}.jar
%{_javadir}*/%{old_name}.jar
%{_javadir}*/%{short_name}-%{version}.jar
%{_javadir}*/%{short_name}.jar

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Tue Jan 18 2011 Permaine Cheung <pcheung@redhat.com> - 0:1.0.2-7.1.3
- Rebuild

* Fri Nov 19 2010 Permaine Cheung <pcheung@redhat.com> - 0:1.0.2-7.1.2
- Add pom, upload.sh and content of maven2-brew to repolib
- Fix %%files for signed jars

* Mon May 17 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.0.2-7.1.1
- rebuilt

* Mon Apr 19 2010 Luiz Barreiros <gbarreir@redhat.com> 0:1.0.2-8
- Rebuild

* Wed Apr 08 2009 David Walluck <dwalluck@redhat.com> 0:1.0.2-7
- fix file list
- fix repolib

* Thu May 29 2008 Permaine Cheung <pcheung@redhat.com> - 0:1.0.2-6
- First JPP5 build

* Tue Mar 13 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:1.0.2-5jpp.ep1.2
- Fix replib location

* Tue Mar 13 2007 Fernando Nasser <fnasser@redhat.com> - 0:1.0.2-5jpp.ep1.1
- Rebuild

* Wed Feb 21 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:1.0.2-5jpp.el4ep1.3
- Install upstream jar file

* Mon Feb 19 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:1.0.2-5jpp.el4ep1.2
- Add -brew suffix

* Fri Feb 16 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:1.0.2-5jpp.el4ep1.1
- Add repolib support

* Tue May 23 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.0.2-5jpp_1rh
- First Red Hat build with new name

* Wed May 04 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.0.2-5jpp
- Change name to gnu-trove, Provide/Obsolete gnu.trove
- Still provide gnu.trove.jar as symlink

* Wed Jan 04 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.0.2-4jpp
- First JPP 1.7 build

* Mon Aug 23 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.0.2-3jpp
- Upgrade to Ant 1.6.X

* Tue Jun 01 2004 Randy Watler <rwatler at finali.com> - 0:1.0.2-2jpp
- Upgrade to Ant 1.6.X

* Tue Feb 24 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.0.2-1jpp
- First JPackage release
